#[repr(u8)]pub enum Address {
Low = 104,
High = 105,
}Expand description
The I2C address for the Grid-EYE sensor.
The names chosen are not because of the actual address values, but because of what the address selection pin is connected to (ground or VDD).
Variants