#[repr(u8)]pub enum FrameRateValue {
Fps1 = 1,
Fps10 = 0,
}Expand description
The frame rate of the camera. Internally, the sensor always runs at 10 FPS, but in 1 FPS mode it is averaging the frames internally to reduce noise. The names are slightly different from those used in the datasheet to conform to Rust’s identifier rules.
Variants