InterruptControlMode

Enum InterruptControlMode 

#[repr(u8)]
pub enum InterruptControlMode { Absolute = 2, Difference = 0, }
How interrupts should be triggered.

Variants



Absolute = 2

Interrupt triggered when an absolute temperature threshold is crossed.



Difference = 0

Interrupt triggered when the change in temperature has exceeded a threshold.