PowerControlValue

Enum PowerControlValue 

#[repr(u8)]
pub enum PowerControlValue { Normal = 0, Sleep = 16, Standby60 = 32, Standby10 = 33, }
On power on, the device is in normal mode. There are no restrictions for leaving normal mode. In sleep mode, the only valid mode to change to is normal mode. When leaving sleep mode the value of other registers are undefined, and must be reset with this procedure:

  1. Set Register::PowerControl to Normal.
  2. Wait 50 milliseconds.
  3. Set Register::Reset to Initial.
  4. Wait 2 milliseconds.
  5. Set Register::Reset to Flag.

The datasheet has a nice state diagram summarizing this.

Variants



Normal = 0

Normal operation.



Sleep = 16

Sleep mode.



Standby60 = 32

Standby mode with the pixel temperature only being updated every 60 seconds.



Standby10 = 33

Standby mode with the pixel temperature only being updated every 10 seconds.