#[repr(u8)]pub enum PowerControlValue {
Normal = 0,
Sleep = 16,
Standby60 = 32,
Standby10 = 33,
}Expand description
On power on, the device is in normal mode. There are no restrictions for leaving normal mode. In sleep mode, the only valid mode to change to is normal mode. When leaving sleep mode the value of other registers are undefined, and must be reset with this procedure:
- Set Register::PowerControl to
Normal. - Wait 50 milliseconds.
- Set Register::Reset to
Initial. - Wait 2 milliseconds.
- Set Register::Reset to
Flag.
The datasheet has a nice state diagram summarizing this.
Variants
Normal = 0
Normal operation.
Sleep = 16
Sleep mode.
Standby60 = 32
Standby mode with the pixel temperature only being updated every 60 seconds.
Standby10 = 33
Standby mode with the pixel temperature only being updated every 10 seconds.